/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.asset.info.display.internal.field;

import com.liferay.asset.info.display.field.AssetEntryInfoDisplayFieldProvider;
import com.liferay.asset.kernel.AssetRendererFactoryRegistryUtil;
import com.liferay.asset.kernel.model.AssetEntry;
import com.liferay.asset.kernel.model.AssetRendererFactory;
import com.liferay.info.display.contributor.field.InfoDisplayContributorField;
import com.liferay.info.display.contributor.field.InfoDisplayContributorFieldTracker;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Jürgen Kappler
 */
@Component(immediate = true, service = AssetEntryInfoDisplayFieldProvider.class)
public class AssetEntryInfoDisplayFieldProviderImpl
	implements AssetEntryInfoDisplayFieldProvider {

	@Override
	public Map<String, Object> getAssetEntryInfoDisplayFieldsValues(
			String className, long classPK, Locale locale)
		throws PortalException {

		Map<String, Object> infoDisplayFieldsValues = new HashMap<>();

		AssetRendererFactory<?> assetRendererFactory =
			AssetRendererFactoryRegistryUtil.getAssetRendererFactoryByClassName(
				className);

		try {
			AssetEntry assetEntry = assetRendererFactory.getAssetEntry(
				className, classPK);

			List<InfoDisplayContributorField<?>> infoDisplayContributorFields =
				_infoDisplayContributorFieldTracker.
					getInfoDisplayContributorFields(AssetEntry.class.getName());

			for (InfoDisplayContributorField<?> infoDisplayContributorField :
					infoDisplayContributorFields) {

				InfoDisplayContributorField<AssetEntry>
					assetEntryInfoDisplayContributorField =
						(InfoDisplayContributorField<AssetEntry>)
							infoDisplayContributorField;

				Object fieldValue =
					assetEntryInfoDisplayContributorField.getValue(
						assetEntry, locale);

				infoDisplayFieldsValues.putIfAbsent(
					assetEntryInfoDisplayContributorField.getKey(), fieldValue);
			}
		}
		catch (PortalException portalException) {
			if (_log.isDebugEnabled()) {
				_log.debug(portalException, portalException);
			}
		}

		return infoDisplayFieldsValues;
	}

	private static final Log _log = LogFactoryUtil.getLog(
		AssetEntryInfoDisplayFieldProviderImpl.class);

	@Reference
	private InfoDisplayContributorFieldTracker
		_infoDisplayContributorFieldTracker;

}